pub struct AggregateNode { /* private fields */ }Expand description
Aggregate node - numeric aggregation.
Performs aggregation operations on numeric values from:
- An array field (aggregates all elements)
- Multiple specified fields (aggregates their values)
Ports
- Input: “in” - Source data with numeric values
- Output: “out” - Object with aggregation result
- Output: “error” - Emitted on errors
Example Configuration
nodes:
calculate_total:
type: std::aggregate
config:
operation: sum
source: $.items[*].price # Array field
output_field: total
inputs:
- from: cart.out -> in
outputs:
out: -> checkout.inImplementations
Sourceimpl AggregateNode
impl AggregateNode
Sourcepub fn array(
array_path: impl Into<String>,
operation: AggregateOperation,
output_field: impl Into<String>,
) -> Self
pub fn array( array_path: impl Into<String>, operation: AggregateOperation, output_field: impl Into<String>, ) -> Self
Create an aggregate node that operates on an array field.
Sourcepub fn array_field(
array_path: impl Into<String>,
value_field: impl Into<String>,
operation: AggregateOperation,
output_field: impl Into<String>,
) -> Self
pub fn array_field( array_path: impl Into<String>, value_field: impl Into<String>, operation: AggregateOperation, output_field: impl Into<String>, ) -> Self
Create an aggregate node that operates on an array of objects, extracting a specific field from each.
Sourcepub fn fields(
fields: Vec<String>,
operation: AggregateOperation,
output_field: impl Into<String>,
) -> Self
pub fn fields( fields: Vec<String>, operation: AggregateOperation, output_field: impl Into<String>, ) -> Self
Create an aggregate node that operates on multiple fields.
Sourcepub fn sum(
array_path: impl Into<String>,
output_field: impl Into<String>,
) -> Self
pub fn sum( array_path: impl Into<String>, output_field: impl Into<String>, ) -> Self
Create a sum aggregation over an array.