pub struct SplitNode { /* private fields */ }Expand description
Split node - fan-out iterator.
Takes an array field from the input and emits each element as a separate output. This enables “for each item” processing patterns.
Ports
- Input: “in” - Data containing an array field
- Output: “out” - Emitted for each item in the array
- Output: “done” - Emitted when all items have been processed
- Output: “error” - Emitted on errors
Example Configuration
nodes:
process_items:
type: std::split
config:
field: $.items # Array field to iterate
mode: parallel # sequential | parallel | batched
batch_size: 10 # Only for batched mode
inputs:
- from: fetch_data.out -> in
outputs:
out: -> process_item.in
done: -> finalize.inImplementations
Sourceimpl SplitNode
impl SplitNode
Sourcepub fn new(field: impl Into<String>) -> Self
pub fn new(field: impl Into<String>) -> Self
Create a split node that iterates over the specified field.
Sourcepub fn sequential(field: impl Into<String>) -> Self
pub fn sequential(field: impl Into<String>) -> Self
Create a split node with sequential processing.
Sourcepub fn parallel(field: impl Into<String>) -> Self
pub fn parallel(field: impl Into<String>) -> Self
Create a split node with parallel processing.