pub struct LoopNode { /* private fields */ }Expand description
Loop node - controlled iteration.
Implements a loop construct for repeated execution. The loop continues until an exit condition is met. Loop back-edges must be declared in the flow topology to be excluded from cycle detection.
Ports
- Input: “in” - Initial input / data from loop body
- Output: “continue” - Activated to continue the loop
- Output: “exit” - Activated when loop terminates
Example Configuration
nodes:
retry_loop:
type: std::loop
config:
max_iterations: 3
# Or: until_true: $.success
# Or: until_expression: "${iteration} >= 3 || ${result.success}"
inputs:
- from: start.out -> in
- from: retry_action.out -> in # back-edge from loop body
outputs:
continue: -> retry_action.in
exit: -> done.inBack-edge Declaration
topology:
loop_edges:
- from: retry_action
to: retry_loop # This edge is treated as a back-edgeImplementations
Sourceimpl LoopNode
impl LoopNode
Sourcepub fn with_max_iterations(max: u32) -> Self
pub fn with_max_iterations(max: u32) -> Self
Create a loop with max iterations exit condition.
Sourcepub fn until_field_equals(
field: impl Into<String>,
value: impl Into<String>,
max_iterations: u32,
) -> Self
pub fn until_field_equals( field: impl Into<String>, value: impl Into<String>, max_iterations: u32, ) -> Self
Create a loop that runs until a field equals a value.
Sourcepub fn until_true(field: impl Into<String>, max_iterations: u32) -> Self
pub fn until_true(field: impl Into<String>, max_iterations: u32) -> Self
Create a loop that runs until a boolean field is true.
Sourcepub fn with_expression(expr: impl Into<String>, max_iterations: u32) -> Self
pub fn with_expression(expr: impl Into<String>, max_iterations: u32) -> Self
Create a loop with a custom exit expression.